#include "svg.h"

using namespace std;

void
svg_begin(double width, double height)
{
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end()
{
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text)
{
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";

}

void svg_rect(double x, double y, double width, double height,
              string stroke = "black", string fill = "#071de8")
{
    cout << "<rect x='" << x << "' y='" << y << "' width='" << width << "' height='" << height << "' stroke='" << stroke << "' fill='" << fill << "' />\n";
}

void
show_histogram_svg(const vector<size_t>& bins)
{
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;
    const auto YELLOW = "yellow";
    const auto RED = "red";
    const auto MAX_WIDTH = IMAGE_WIDTH-TEXT_WIDTH;

    svg_begin(IMAGE_WIDTH, IMAGE_HEIGHT);

    size_t min,max;
     min = bins[0];
    max = bins[0];
for (size_t bin : bins)
    {
        if (bin < min)
        {
            min = bin;
        }
        else if (bin > max)
        {
            max = bin;
        }
    }

    double top = 0;
    for (size_t bin : bins)
    { if (bin == max) {
        const double bin_width = BLOCK_WIDTH * bin;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
        svg_rect(TEXT_WIDTH, top, MAX_WIDTH, BIN_HEIGHT);
        top += BIN_HEIGHT;
    }
    else{
        const double bin_width = BLOCK_WIDTH * bin;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT);
        top += BIN_HEIGHT;
    }
    }
    svg_end();
}
